<?php
use Monolog\Logger;
use Monolog\Handler\StreamHandler;

return [
    'basePath' => realpath(__DIR__ . '/../'),
    'defaultLayoutPath' => '@app/modules/site/layouts',
    'defaultLayout' => 'main',
    'errorRoute' => 'site/default/error',
    'language' => getenv('APP_LANGUAGE'),
    'components' => [
        'Piko\View' => [
            'themeMap' => [
                '@app/modules/user/views' => '@app/overrides/user/views',
            ],
        ],
        'Piko\Router' => [
            'construct' => [
                [
                    'routes' => require __DIR__ . '/routes.php',
                ]
            ]
        ],
        'Piko\User' => [
            'identityClass' => 'app\overrides\user\models\User',
            'checkAccess' => 'app\modules\user\AccessChecker::checkAccess'
        ],
        'Monolog\Logger' => function() {
            // create a log channel
            $logger = new Logger('app');
            $level = getenv('APP_DEBUG') ? Logger::DEBUG : Logger::ERROR;
            $logger->pushHandler(new StreamHandler( __DIR__ . '/../var/log/app.log', $level));

            return $logger;
        },
        'PDO' => [
            'construct' => [
                'sqlite:' . getenv('SQLITE_DB')
            ]
        ],
        'Piko\I18n' => [
            'language' => getenv('APP_LANGUAGE'),
            'translations' => [
                'user' => '@app/modules/user/messages'
            ]
        ],
        'Nette\Mail\SmtpMailer' => [
            'construct' => [
                getenv('SMTP_HOST'),
                getenv('SMTP_USER'),
                getenv('SMTP_PASSWORD'),
                (int) getenv('SMTP_PORT'),
                getenv('SMTP_ENCRYPTION'),
            ]
        ],
    ],
    'modules' => [
        'site' => 'app\modules\site\Module',
        'user' => [
            'class' => 'app\modules\user\Module',
            'controllerMap' => [
                'default' => 'app\overrides\user\controllers\DefaultController',
            ]
        ],
    ],
    'bootstrap' => ['site', 'user']
];
