// src/lib/clipboard.js

export function copyToClipboard(text) {
    if (navigator.clipboard) {
      return navigator.clipboard.writeText(text);
    }

    return fallbackCopyToClipboard(text);
  }

  function fallbackCopyToClipboard(text) {
    return new Promise((resolve, reject) => {
      const textArea = document.createElement("textarea");
      textArea.value = text;

      // Éviter le scrolling vers le bas
      textArea.style.position = "fixed";
      textArea.style.top = "-9999px";

      document.body.appendChild(textArea);
      textArea.focus();
      textArea.select();

      if (document.execCommand('copy')) {
        resolve();
      } else {
        reject(new Error('Fallback: Copy command was unsuccessful'));
      }

      document.body.removeChild(textArea);
    });
  }
